==> xl-react-components-0.18.103.tgz: package/app/pages/playground/split-pane-test-component.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';

import {XlReactWidgetCollapsibleBottomSplitPanel} from '../../xl-react-widget/xl-react-widget-split-panel/xl-react-widget-collapsible-bottom-split-pane/xl-react-widget-collapsible-bottom-split-pane-component'; // eslint-disable-line max-len
import {XlReactWidgetCollapsibleVerticalSplitPanel} from '../../xl-react-widget/xl-react-widget-split-panel/xl-react-widget-collapsible-vertical-split-pane/xl-react-widget-collapsible-vertical-split-pane-component'; // eslint-disable-line max-len
import KitchenTestComponent from './kitchen-test-component';

import '../../images/udm.Application.svg';

export const ORIENTATION = {HORIZONTAL: 'HORIZONTAL', VERTICAL: 'VERTICAL'};

export class SplitPaneTestComponent extends PureComponent {
    static propTypes = {
        api: PropTypes.object,
        children: PropTypes.oneOfType([
            PropTypes.element,
            PropTypes.array
        ]).isRequired,
        className: PropTypes.string,
        currentState: PropTypes.object.isRequired,
        modelName: PropTypes.string.isRequired,
        orientation: PropTypes.oneOf([ORIENTATION.HORIZONTAL, ORIENTATION.VERTICAL]),
        updateState: PropTypes.func.isRequired
    };

    render() {
        const {
            children, className, currentState, modelName, orientation, updateState
        } = this.props;
        const componentState = currentState[modelName];

        const getComponent = () => orientation === ORIENTATION.HORIZONTAL ?
            <XlReactWidgetCollapsibleBottomSplitPanel
                defaultBottomPaneHeight={componentState.defaultPaneHeight}
                minSizeBottom={componentState.minSizeBottom}
                minSizeTop={componentState.minSizeTop}>
                {children}
            </XlReactWidgetCollapsibleBottomSplitPanel> :
            <XlReactWidgetCollapsibleVerticalSplitPanel
                isCollapsed={componentState.isCollapsed}
                minPrimarySideWidth={componentState.minPrimarySideWidth}
                minSecondarySideWidth={componentState.minSecondarySideWidth}
                primary={componentState.primary}
                primarySideWidth={componentState.primarySideWidth}
                shouldAnimate={componentState.shouldAnimate}
                sideToCollapse={componentState.sideToCollapse}>
                {children}
            </XlReactWidgetCollapsibleVerticalSplitPanel>;

        return <KitchenTestComponent
            className={className}
            currentState={currentState}
            modelName={modelName}
            showBindings={componentState.showBindings}
            updateState={updateState}>
            {getComponent()}
        </KitchenTestComponent>;
    }
}

==> xl-react-components-0.21.15.tgz: package/app/pages/playground/split-pane-test-component.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';

import {XlReactWidgetCollapsibleBottomSplitPanel} from '../../xl-react-widget/xl-react-widget-split-panel/xl-react-widget-collapsible-bottom-split-pane/xl-react-widget-collapsible-bottom-split-pane-component'; // eslint-disable-line max-len
import {XlReactWidgetCollapsibleVerticalSplitPanel} from '../../xl-react-widget/xl-react-widget-split-panel/xl-react-widget-collapsible-vertical-split-pane/xl-react-widget-collapsible-vertical-split-pane-component'; // eslint-disable-line max-len
import WidgetKitchenTestComponent from './widget-kitchen-test-component';

import '../../images/udm.Application.svg';

export const ORIENTATION = {HORIZONTAL: 'HORIZONTAL', VERTICAL: 'VERTICAL'};

export class SplitPaneTestComponent extends PureComponent {
    static propTypes = {
        allowResize: PropTypes.bool,
        api: PropTypes.object,
        children: PropTypes.oneOfType([
            PropTypes.element,
            PropTypes.array
        ]).isRequired,
        className: PropTypes.string,
        currentState: PropTypes.object.isRequired,
        modelName: PropTypes.string.isRequired,
        orientation: PropTypes.oneOf([ORIENTATION.HORIZONTAL, ORIENTATION.VERTICAL]),
        updateState: PropTypes.func.isRequired
    };

    render() {
        const {
            allowResize, children, className, currentState, modelName, orientation, updateState
        } = this.props;
        const componentState = currentState[modelName];

        const getComponent = () => orientation === ORIENTATION.HORIZONTAL ?
            <XlReactWidgetCollapsibleBottomSplitPanel
                allowResize={allowResize}
                defaultBottomPaneHeight={componentState.defaultPaneHeight}
                minSizeBottom={componentState.minSizeBottom}
                minSizeTop={componentState.minSizeTop}>
                {children}
            </XlReactWidgetCollapsibleBottomSplitPanel> :
            <XlReactWidgetCollapsibleVerticalSplitPanel
                allowResize={allowResize}
                isCollapsed={componentState.isCollapsed}
                minPrimarySideWidth={componentState.minPrimarySideWidth}
                minSecondarySideWidth={componentState.minSecondarySideWidth}
                primary={componentState.primary}
                primarySideWidth={componentState.primarySideWidth}
                shouldAnimate={componentState.shouldAnimate}
                sideToCollapse={componentState.sideToCollapse}>
                {children}
            </XlReactWidgetCollapsibleVerticalSplitPanel>;

        return <WidgetKitchenTestComponent
            className={className}
            currentState={currentState}
            modelName={modelName}
            showBindings={componentState.showBindings}
            updateState={updateState}>
            {getComponent()}
        </WidgetKitchenTestComponent>;
    }
}
